# This file is generated by objective.metadata
#
# Last update: Sun Mar 22 17:16:16 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$PSEnclosureDownloadStateDidChangeNotification$PSErrorDomain$PSFeedAddedEntriesKey$PSFeedDidChangeEntryFlagsKey$PSFeedEntriesChangedNotification$PSFeedRefreshingNotification$PSFeedRemovedEntriesKey$PSFeedUpdatedEntriesKey$"""
enums = """$PSAtomFormat@2$PSEnclosureDownloadDidFail@4$PSEnclosureDownloadDidFinish@3$PSEnclosureDownloadIsActive@2$PSEnclosureDownloadIsIdle@0$PSEnclosureDownloadIsQueued@1$PSEnclosureDownloadWasDeleted@5$PSFeedSettingsUnlimitedSize@0$PSInternalError@1$PSLinkToAlternate@7$PSLinkToAtom@2$PSLinkToAtomService@3$PSLinkToFOAF@4$PSLinkToOther@0$PSLinkToRSD@5$PSLinkToRSS@1$PSLinkToSelf@6$PSNotAFeedError@2$PSRSSFormat@1$PSUnknownFormat@0$"""
misc.update(
    {
        "PSFeedSettingsIntervalNever": -1.0,
        "PSFeedSettingsAllTypes": None,
        "PSFeedSettingsIntervalDefault": 0.0,
    }
)
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSObject",
        b"enclosure:downloadStateDidChange:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}, 3: {"type": b"i"}}},
    )
    r(
        b"NSObject",
        b"feed:didAddEntries:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"feed:didChangeFlagsInEntries:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"feed:didRemoveEntriesWithIdentifiers:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"feed:didUpdateEntries:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"feedDidBeginRefresh:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"feedDidEndRefresh:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(b"PSClient", b"addFeed:", {"retval": {"type": "Z"}})
    r(b"PSClient", b"isPrivate", {"retval": {"type": "Z"}})
    r(b"PSClient", b"removeFeed:", {"retval": {"type": "Z"}})
    r(b"PSClient", b"setPrivate:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"PSEnclosure",
        b"download:",
        {"retval": {"type": "Z"}, "arguments": {2: {"type_modifier": b"o"}}},
    )
    r(b"PSEntry", b"isCurrent", {"retval": {"type": "Z"}})
    r(b"PSEntry", b"isFlagged", {"retval": {"type": "Z"}})
    r(b"PSEntry", b"isRead", {"retval": {"type": "Z"}})
    r(b"PSEntry", b"setCurrent:", {"arguments": {2: {"type": "Z"}}})
    r(b"PSEntry", b"setFlagged:", {"arguments": {2: {"type": "Z"}}})
    r(b"PSEntry", b"setRead:", {"arguments": {2: {"type": "Z"}}})
    r(b"PSFeed", b"XMLRepresentationWithEntries:", {"arguments": {2: {"type": "Z"}}})
    r(b"PSFeed", b"isRefreshing", {"retval": {"type": "Z"}})
    r(
        b"PSFeed",
        b"refresh:",
        {"retval": {"type": "Z"}, "arguments": {2: {"type_modifier": b"o"}}},
    )
    r(b"PSFeedSettings", b"downloadsEnclosures", {"retval": {"type": "Z"}})
    r(b"PSFeedSettings", b"refreshesInBackground", {"retval": {"type": "Z"}})
    r(b"PSFeedSettings", b"setDownloadsEnclosures:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"PSFeedSettings",
        b"setRefreshesInBackground:",
        {"arguments": {2: {"type": "Z"}}},
    )
finally:
    objc._updatingMetadata(False)
protocols = {
    "PSClientDelegate": objc.informal_protocol(
        "PSClientDelegate",
        [
            objc.selector(None, b"feed:didUpdateEntries:", b"v@:@@", isRequired=False),
            objc.selector(None, b"feedDidBeginRefresh:", b"v@:@", isRequired=False),
            objc.selector(
                None, b"enclosure:downloadStateDidChange:", b"v@:@i", isRequired=False
            ),
            objc.selector(
                None,
                b"feed:didRemoveEntriesWithIdentifiers:",
                b"v@:@@",
                isRequired=False,
            ),
            objc.selector(None, b"feedDidEndRefresh:", b"v@:@", isRequired=False),
            objc.selector(None, b"feed:didAddEntries:", b"v@:@@", isRequired=False),
            objc.selector(
                None, b"feed:didChangeFlagsInEntries:", b"v@:@@", isRequired=False
            ),
        ],
    )
}
expressions = {}

# END OF FILE



import PubSub
from PyObjCTools.TestSupport import TestCase


class TestPSClient(TestCase):
    def testMethods(self):
        self.assertResultIsBOOL(PubSub.PSClient.addFeed_)
        self.assertResultIsBOOL(PubSub.PSClient.removeFeed_)
        self.assertResultIsBOOL(PubSub.PSClient.isPrivate)
        self.assertArgIsBOOL(PubSub.PSClient.setPrivate_, 0)



import PubSub
from PyObjCTools.TestSupport import TestCase


class TestPSFeed(TestCase):
    def testConstants(self):
        self.assertIsInstance(PubSub.PSErrorDomain, str)

        self.assertEqual(PubSub.PSInternalError, 1)
        self.assertEqual(PubSub.PSNotAFeedError, 2)

        self.assertEqual(PubSub.PSUnknownFormat, 0)
        self.assertEqual(PubSub.PSRSSFormat, 1)
        self.assertEqual(PubSub.PSAtomFormat, 2)

        self.assertIsInstance(PubSub.PSFeedRefreshingNotification, str)
        self.assertIsInstance(PubSub.PSFeedEntriesChangedNotification, str)
        self.assertIsInstance(PubSub.PSFeedAddedEntriesKey, str)
        self.assertIsInstance(PubSub.PSFeedRemovedEntriesKey, str)
        self.assertIsInstance(PubSub.PSFeedUpdatedEntriesKey, str)
        self.assertIsInstance(PubSub.PSFeedDidChangeEntryFlagsKey, str)

    def testMethods(self):
        self.assertResultIsBOOL(PubSub.PSFeed.isRefreshing)
        self.assertResultIsBOOL(PubSub.PSFeed.refresh_)
        self.assertArgIsOut(PubSub.PSFeed.refresh_, 0)
        self.assertArgIsBOOL(PubSub.PSFeed.XMLRepresentationWithEntries_, 0)



import PubSub
from PyObjCTools.TestSupport import TestCase


class TestPSEntry(TestCase):
    def testMethods(self):
        self.assertResultIsBOOL(PubSub.PSEntry.isCurrent)
        self.assertResultIsBOOL(PubSub.PSEntry.isRead)
        self.assertArgIsBOOL(PubSub.PSEntry.setRead_, 0)
        self.assertResultIsBOOL(PubSub.PSEntry.isFlagged)
        self.assertArgIsBOOL(PubSub.PSEntry.setFlagged_, 0)



"""
Some simple tests to check that the framework is properly wrapped.
"""
import objc
import PubSub
from PyObjCTools.TestSupport import TestCase


class TestPubSub(TestCase):
    def testClasses(self):
        self.assertTrue(hasattr(PubSub, "PSAuthor"))
        self.assertTrue(isinstance(PubSub.PSAuthor, objc.objc_class))

    def testProtocols(self):
        self.assertFalse(hasattr(PubSub, "protocols"))
        # self.assertTrue( hasattr(PubSub.protocols, 'PSClientDelegate') )
        # self.assertTrue( isinstance(PubSub.protocols.PSClientDelegate, objc.informal_protocol) )



import PubSub
from PyObjCTools.TestSupport import TestCase


class TestPSFeedSettings(TestCase):
    def testConstants(self):
        self.assertEqual(PubSub.PSFeedSettingsIntervalDefault, 0.0)
        self.assertEqual(PubSub.PSFeedSettingsIntervalNever, -1.0)
        self.assertEqual(PubSub.PSFeedSettingsUnlimitedSize, 0)
        self.assertEqual(PubSub.PSFeedSettingsAllTypes, None)

    def testMethods(self):
        self.assertResultIsBOOL(PubSub.PSFeedSettings.refreshesInBackground)
        self.assertArgIsBOOL(PubSub.PSFeedSettings.setRefreshesInBackground_, 0)

        self.assertResultIsBOOL(PubSub.PSFeedSettings.downloadsEnclosures)
        self.assertArgIsBOOL(PubSub.PSFeedSettings.setDownloadsEnclosures_, 0)



import PubSub
from PyObjCTools.TestSupport import TestCase


class TestPSEnclosure(TestCase):
    def testConstants(self):
        self.assertEqual(PubSub.PSEnclosureDownloadIsIdle, 0)
        self.assertEqual(PubSub.PSEnclosureDownloadIsQueued, 1)
        self.assertEqual(PubSub.PSEnclosureDownloadIsActive, 2)
        self.assertEqual(PubSub.PSEnclosureDownloadDidFinish, 3)
        self.assertEqual(PubSub.PSEnclosureDownloadDidFail, 4)
        self.assertEqual(PubSub.PSEnclosureDownloadWasDeleted, 5)

        self.assertIsInstance(PubSub.PSEnclosureDownloadStateDidChangeNotification, str)

    def testMethods(self):
        self.assertResultIsBOOL(PubSub.PSEnclosure.download_)
        self.assertArgIsOut(PubSub.PSEnclosure.download_, 0)



import PubSub
from PyObjCTools.TestSupport import TestCase


class TestPSLink(TestCase):
    def testConstants(self):
        self.assertEqual(PubSub.PSLinkToOther, 0)
        self.assertEqual(PubSub.PSLinkToRSS, 1)
        self.assertEqual(PubSub.PSLinkToAtom, 2)
        self.assertEqual(PubSub.PSLinkToAtomService, 3)
        self.assertEqual(PubSub.PSLinkToFOAF, 4)
        self.assertEqual(PubSub.PSLinkToRSD, 5)
        self.assertEqual(PubSub.PSLinkToSelf, 6)
        self.assertEqual(PubSub.PSLinkToAlternate, 7)



"""
Wrappers for the "PubSub" framework on macOS 10.5 or later.  This framework
offers developers a way to subscribe to web feeds (RSS, Atom) from their
applications.

These wrappers don't include documentation, please check Apple's documentation
for information on how to use this framework and PyObjC's documentation
for general tips and tricks regarding the translation between Python
and (Objective-)C frameworks

Note that this framework is deprecated in OSX 10.9
"""
from pyobjc_setup import setup

VERSION = "8.1"

setup(
    name="pyobjc-framework-PubSub",
    description="Wrappers for the framework PubSub on macOS",
    min_os_level="10.5",
    max_os_level="10.14",
    packages=["PubSub"],
    version=VERSION,
    install_requires=["pyobjc-core>=" + VERSION, "pyobjc-framework-Cocoa>=" + VERSION],
    long_description=__doc__,
)
